### R code from vignette source 'join.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: join.Rnw:23-26
###################################################
library(ref2014)
data(ref2014)
data(hesa2014)


###################################################
### code chunk number 2: join.Rnw:29-31
###################################################
hesa2014.columns <- c("INSTID","UKPRN","Region","UOA","msubId","EligibleFte")
join2014 <- merge(ref2014, hesa2014[,hesa2014.columns], all=TRUE)


###################################################
### code chunk number 3: join.Rnw:47-50
###################################################
library(dplyr)
library(ggplot2)
library(scales)


###################################################
### code chunk number 4: join.Rnw:63-78
###################################################
overall2014 <- join2014 %>%
    filter(is.na(Profile) | Profile == "Overall") %>%
    group_by(UKPRN) %>%
    summarise(FourStar=weighted.mean(FourStar, StaffFte, na.rm=TRUE),
              ThreeStar=weighted.mean(ThreeStar, StaffFte, na.rm=TRUE),
              TwoStar=weighted.mean(TwoStar, StaffFte, na.rm=TRUE),
              OneStar=weighted.mean(OneStar, StaffFte, na.rm=TRUE),
              Unclassified=weighted.mean(Unclassified, StaffFte, na.rm=TRUE),
              Institution=first(Institution[!is.na(Institution)]),
              nUOA=n(),
              StaffFte=sum(StaffFte, na.rm=TRUE),
              EligibleFte=sum(EligibleFte, na.rm=TRUE)) %>%
    filter(StaffFte <= EligibleFte, StaffFte > 0) %>%
    mutate(QR=3*FourStar+ThreeStar) %>%
    mutate(QR.I=QR*StaffFte/EligibleFte)


###################################################
### code chunk number 5: join.Rnw:85-104
###################################################
step <- 1
left <- sprintf("%s %.0f", overall2014$Institution, overall2014$QR)
right <- sprintf("%.0f %s", overall2014$QR.I, overall2014$Institution)
p <- ggplot(overall2014) 
p <- p + geom_segment(aes(x=0, xend=step, y=QR, yend=QR.I,
                          alpha=0.5+ifelse(QR==0, 0, 0.5*abs(QR-QR.I)/(QR+QR.I))),
                      size=0.1)
p <- p + theme(panel.background=element_blank(), panel.grid=element_blank(), 
               axis.ticks=element_blank(), axis.text=element_blank(),
               panel.border=element_blank(), legend.position="none",
               axis.line=element_blank())
p <- p + xlab("") + ylab("") + xlim((0-1), (step+1)) + ylim(0, 214)
p <- p + geom_text(label=right, y=overall2014$QR.I, x=step+0.025, hjust=0, size=3.5)
p <- p + geom_text(label=left, y=overall2014$QR, x=-0.025, hjust=1, size=3.5)
p <- p + geom_text(data=data.frame(x=1), label="QR (3:1)", x=-0.025, y=210, hjust=1, size=5) +
    geom_text(data=data.frame(x=1), label="QR (3:1) Intensity",
              x=step+0.025, y=210, hjust=0, size=5) +
    geom_text(data=data.frame(x=1), label="Overall", x=0.5, y=213, size=6)
print(p)


